@@ -4,9 +4,8 @@ use Mojo::Base 'Mojolicious::Plugin';
 use List::Util 'first';
 use Mojo::Loader ();
 use Mojo::Util 'camelize';
-use Scalar::Util 'weaken';
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 has models => sub { {} };
 
@@ -20,6 +19,7 @@ sub register {
     model => sub {
       my ($self, $name) = @_;
 
+      $name = $conf->{default} unless defined($name);
       $name = camelize($name) if $name =~ /^[a-z]/;
 
       my $model;
@@ -33,9 +33,8 @@ sub register {
           next;
         }
 
-        $model = $class->new(app => $app);
-        weaken $model->{app};
-
+        $model =
+          $class->new(ref($conf->{params}{$name}) eq 'HASH' ? %{$conf->{params}{$name}} : (), app => $app);
         $plugin->models->{$name} = $model;
         return $model;
       }
@@ -49,7 +48,7 @@ sub register {
 sub _load_class {
   my $class = shift;
 
-  my $error = Mojolicious->VERSION < 6 ? Mojo::Loader->new->load($class) : Mojo::Loader::load_class($class);
+  my $error = Mojo::Loader->can('new') ? Mojo::Loader->new->load($class) : Mojo::Loader::load_class($class);
 
   return 1 unless $error;
   die $error if ref $error;
@@ -126,6 +125,18 @@ Mojolicious::Lite application
 
   app->start;
 
+All available options
+
+  #!/usr/bin/env perl
+  use Mojolicious::Lite;
+
+  plugin Model => {
+    namespaces   => ['MyApp::Model', 'MyApp::CLI::Model'],
+    base_classes => ['MyApp::Model'],
+    default      => 'MyApp::Model::Pg',
+    params => {Pg => {uri => 'postgresql://user@/mydb'}}
+  };
+
 =head1 DESCRIPTION
 
 L<Mojolicious::Plugin::Model> is a Model (M in MVC architecture) for Mojolicious applications. Each
@@ -149,6 +160,27 @@ Namespace to load models from, defaults to C<$moniker::Model>.
 
 Base classes used to identify models, defaults to L<MojoX::Model>.
 
+=head2 default
+
+  # Mojolicious::Lite
+  plugin Model => {default => 'MyModel'};
+
+  any '/' => sub {
+    my $c = shift();
+    $c->model->do(); # used model MyModel
+    # ...
+  }
+
+The name of the default model to use if the name of the current model not
+specified.
+
+=head2 params
+
+  # Mojolicious::Lite
+  plugin Model => {params => {DBI => {dsn => 'dbi:mysql:mydb'}}};
+
+Parameters to be passed to the class constructor of the model.
+
 =head1 HELPERS
 
 L<Mojolicious::Plugin::Model> implements the following helpers.
@@ -178,7 +210,7 @@ L<Mojolicious>, L<Mojolicious::Guides>, L<http://mojolicio.us>.
 
 Andrey Khozov, C<avkhozov@googlemail.com>.
 
-=head1 CREDITS
+=head1 CONTRIBUTORS
 
 Denis Ibaev, C<dionys@gmail.com>.
 
